==> acquia_dam-1.0.2.tar.gz: acquia_dam/tests/src/Kernel/StreamWrapper/FocalPointIntegrationTest.php <==
<?php

namespace Drupal\Tests\acquia_dam\StreamWrapper;

use Drupal\image\Entity\ImageStyle;
use Drupal\Tests\acquia_dam\Kernel\AcquiaDamKernelTestBase;

/**
 * Focal point integration test.
 *
 * @requires module focal_point
 * @requires module crop
 *
 * @group acquia_dam
 */
class FocalPointIntegrationTest extends AcquiadamKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'crop',
    'focal_point',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    $this->checkRequirements();
    parent::setUp();

    $this->installEntitySchema('crop');
    $this->grantDamDomain();
    $this->setDamSiteToken();
  }

  /**
   * Tests external url generation with focal point crop and scale effect.
   *
   * @param int $crop_width
   *   Crop width.
   * @param int $crop_height
   *   Crop height.
   * @param string $expected_string
   *   Expected query string.
   *
   * @testWith [200, 200, "?crop=yes&w=200&h=200"]
   *           [500, 500, "?crop=yes&w=500&h=500"]
   *           [100, 50, "?crop=yes&w=100&h=50"]
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testFocalPointCropAndScale(int $crop_width, int $crop_height, string $expected_string): void {
    $image_style = ImageStyle::create(['name' => 'test']);
    $image_style->save();
    $image_style_id = $image_style->id();

    $effect = [
      'id' => 'focal_point_scale_and_crop',
      'data' => [
        'width' => $crop_width,
        'height' => $crop_height,
        'crop_type' => 'focal_point',
      ],
    ];

    $image_style->addImageEffect($effect);
    $image_style->save();

    $derivative_uri = $image_style->buildUri('acquia-dam://56ff14de-02cd-41b5-9a73-c917eab19abf');
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);

    // Build uri attach the extension given in the image style into the URI.
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);
    $wrapper = $this->container->get('stream_wrapper_manager')->getViaUri($derivative_uri);
    self::assertEquals("https://laser.widen.net/content/kcnabdscl5/web/Wheel%20Illustration.ai$expected_string", $wrapper->getExternalUrl());

  }

  /**
   * Tests external url generation with focal point crop effect.
   *
   * @param int $x
   *   The "x" value of crop position.
   * @param int $y
   *   The "y" value of crop position.
   * @param string $expected_string
   *   Expected query string.
   * @param int $crop_width
   *   Crop width.
   * @param int $crop_height
   *   Crop height.
   *
   * @dataProvider focalPointDataProvider
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testFocalPointCropEffect(int $x, int $y, string $expected_string, int $crop_width, int $crop_height): void {
    $image_style = ImageStyle::create(['name' => 'test']);
    $image_style->save();
    $image_style_id = $image_style->id();

    $effect = [
      'id' => 'focal_point_crop',
      'data' => [
        'width' => $crop_width,
        'height' => $crop_height,
        'crop_type' => 'focal_point',
      ],
    ];

    $this->mockCropEntity($x, $y);

    $image_style->addImageEffect($effect);
    $image_style->save();

    $derivative_uri = $image_style->buildUri('acquia-dam://56ff14de-02cd-41b5-9a73-c917eab19abf');
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);

    // Build uri attach the extension given in the image style into the URI.
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);
    $wrapper = $this->container->get('stream_wrapper_manager')->getViaUri($derivative_uri);
    self::assertEquals("https://laser.widen.net/content/kcnabdscl5/web/Wheel%20Illustration.ai$expected_string", $wrapper->getExternalUrl());
  }

  /**
   * Data provider for testFocalPointIntegration().
   *
   * @phpstan-return \Generator<string, []>
   */
  public function focalPointDataProvider(): \Generator {
    yield 'crop_middle' => [
      80,
      60,
      '?crop=yes&w=50&h=50&a=55,35',
      50,
      50,
    ];
    yield 'crop_middle_differen_size' => [
      80,
      60,
      '?crop=yes&w=70&h=30&a=45,45',
      70,
      30,
    ];
    yield 'crop_top_left' => [
      0,
      0,
      '?crop=yes&w=50&h=50&a=0,0',
      50,
      50,
    ];
    yield 'crop_top_right' => [
      157,
      0,
      '?crop=yes&w=50&h=50&a=107,0',
      50,
      50,
    ];
    yield 'crop_bottom_left' => [
      0,
      120,
      '?crop=yes&w=50&h=50&a=0,70',
      50,
      50,
    ];
    yield 'crop_invalid' => [
      0,
      0,
      '',
      500,
      500,
    ];
  }

  /**
   * Creates a mock crop entity.
   *
   * @param int $x
   *   Crop height.
   * @param int $y
   *   Crop width.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function mockCropEntity(int $x, int $y): void {
    $values = [
      'type' => 'focal_point',
      'entity_type' => 'file',
      'uri' => 'acquia-dam://styles/test/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf',
    ];

    $crop = \Drupal::entityTypeManager()
      ->getStorage('crop')
      ->create($values);
    $crop->setPosition($x, $y);
    $crop->save();
  }

}

==> acquia_dam-1.0.3.tar.gz: acquia_dam/tests/src/Kernel/StreamWrapper/FocalPointIntegrationTest.php <==
<?php

namespace Drupal\Tests\acquia_dam\StreamWrapper;

use Drupal\image\Entity\ImageStyle;
use Drupal\Tests\acquia_dam\Kernel\AcquiaDamKernelTestBase;

/**
 * Focal point integration test.
 *
 * @requires module focal_point
 * @requires module crop
 *
 * @group acquia_dam
 */
class FocalPointIntegrationTest extends AcquiadamKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'crop',
    'focal_point',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    $this->checkRequirements();
    parent::setUp();

    $this->installEntitySchema('crop');
    $this->grantDamDomain();
    $this->setDamSiteToken();
  }

  /**
   * Tests external url generation with focal point crop and scale effect.
   *
   * @param int $crop_width
   *   Crop width.
   * @param int $crop_height
   *   Crop height.
   * @param string $expected_string
   *   Expected query string.
   *
   * @testWith [200, 200, "?crop=yes&w=200&h=200"]
   *           [500, 500, "?crop=yes&w=500&h=500"]
   *           [100, 50, "?crop=yes&w=100&h=50"]
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testFocalPointCropAndScale(int $crop_width, int $crop_height, string $expected_string): void {
    $image_style = ImageStyle::create(['name' => 'test']);
    $image_style->save();
    $image_style_id = $image_style->id();

    $effect = [
      'id' => 'focal_point_scale_and_crop',
      'data' => [
        'width' => $crop_width,
        'height' => $crop_height,
        'crop_type' => 'focal_point',
      ],
    ];

    $image_style->addImageEffect($effect);
    $image_style->save();

    $derivative_uri = $image_style->buildUri('acquia-dam://56ff14de-02cd-41b5-9a73-c917eab19abf');
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);

    // Build uri attach the extension given in the image style into the URI.
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);
    $wrapper = $this->container->get('stream_wrapper_manager')->getViaUri($derivative_uri);
    self::assertEquals("https://laser.widen.net/content/kcnabdscl5/web/Wheel%20Illustration.ai$expected_string", $wrapper->getExternalUrl());

  }

  /**
   * Tests external url generation with focal point crop effect.
   *
   * @param int $x
   *   The "x" value of crop position.
   * @param int $y
   *   The "y" value of crop position.
   * @param string $expected_string
   *   Expected query string.
   * @param int $crop_width
   *   Crop width.
   * @param int $crop_height
   *   Crop height.
   *
   * @dataProvider focalPointDataProvider
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testFocalPointCropEffect(int $x, int $y, string $expected_string, int $crop_width, int $crop_height): void {
    $image_style = ImageStyle::create(['name' => 'test']);
    $image_style->save();
    $image_style_id = $image_style->id();

    $effect = [
      'id' => 'focal_point_crop',
      'data' => [
        'width' => $crop_width,
        'height' => $crop_height,
        'crop_type' => 'focal_point',
      ],
    ];

    $this->mockCropEntity($x, $y);

    $image_style->addImageEffect($effect);
    $image_style->save();

    $derivative_uri = $image_style->buildUri('acquia-dam://56ff14de-02cd-41b5-9a73-c917eab19abf');
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);

    // Build uri attach the extension given in the image style into the URI.
    self::assertEquals("acquia-dam://styles/$image_style_id/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf", $derivative_uri);
    $wrapper = $this->container->get('stream_wrapper_manager')->getViaUri($derivative_uri);
    self::assertEquals("https://laser.widen.net/content/kcnabdscl5/web/Wheel%20Illustration.ai$expected_string", $wrapper->getExternalUrl());
  }

  /**
   * Data provider for testFocalPointIntegration().
   *
   * @phpstan-return \Generator<string, []>
   */
  public function focalPointDataProvider(): \Generator {
    yield 'crop_middle' => [
      80,
      60,
      '?crop=yes&w=50&h=50&a=55,35',
      50,
      50,
    ];
    yield 'crop_middle_different_size' => [
      80,
      60,
      '?crop=yes&w=70&h=30&a=45,45',
      70,
      30,
    ];
    yield 'crop_top_left' => [
      0,
      0,
      '?crop=yes&w=50&h=50&a=0,0',
      50,
      50,
    ];
    yield 'crop_top_right' => [
      157,
      0,
      '?crop=yes&w=50&h=50&a=107,0',
      50,
      50,
    ];
    yield 'crop_bottom_left' => [
      0,
      120,
      '?crop=yes&w=50&h=50&a=0,70',
      50,
      50,
    ];
    yield 'crop_invalid' => [
      0,
      0,
      '',
      500,
      500,
    ];
  }

  /**
   * Creates a mock crop entity.
   *
   * @param int $x
   *   Crop height.
   * @param int $y
   *   Crop width.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function mockCropEntity(int $x, int $y): void {
    $values = [
      'type' => 'focal_point',
      'entity_type' => 'file',
      'uri' => 'acquia-dam://styles/test/acquia-dam/56ff14de-02cd-41b5-9a73-c917eab19abf',
    ];

    $crop = \Drupal::entityTypeManager()
      ->getStorage('crop')
      ->create($values);
    $crop->setPosition($x, $y);
    $crop->save();
  }

}
